@@ -303,7 +303,7 @@ class VenueDetailsWindow(UberSquareWindow):
 			description_label.setWordWrap(True)
 			gridLayout.addWidget(description_label, i, 0, 1, 2)
 			i += 1
-			gridLayout.addWidget(Rules(), i, 0, 1, 2)
+			gridLayout.addWidget(Ruler(), i, 0, 1, 2)
 
 		i += 1
 		gridLayout.addWidget(QLabel(times, self), i, 0)
